OC.L10N.register(
    "circles",
    {
    "Circles" : "Кола",
    "Circles' files" : "Файли кіл",
    "Select circles to filter by" : "Виберіть кола для фільтрування",
    "No circles found" : "Кола не знайдено",
    "Please select circles to filter by" : "Виберіть кола для фільтрування",
    "No files found for the selected circles" : "Не знайдено файлів для вибраних кіл",
    "You created the circle {circle}" : "Ви створили коло {circle}",
    "{author} created the circle {circle}" : "{author} створив коло {circle}",
    "You deleted {circle}" : "Ви вилучили коло {circle}",
    "{author} deleted {circle}" : "{author} вилучив коло {circle}",
    "You linked {group} to {circle}" : "Ви приєднали {group} до {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} було пов’язано з {circle} автором {author}",
    "You unlinked {group} from {circle}" : "Ви від’єднали {group} від {circle}",
    "{group} has been unlinked from {circle} by {author}" : "Користувач {author} від’єднав {group} від {circle}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Ви змінили рівень пов’язаної групи {group} у {circle} на %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} змінив рівень пов’язаної групи {group} у колі {circle} на %1$s",
    "You sent a request to link {circle} with {remote}" : "Ви надіслали запит на зв’язування {circle} із {remote} ",
    "{author} sent a request to link {circle} with {remote}" : "{author} надіслав запит на зв’язування {circle} із {remote} ",
    "{remote} requested a link with {circle}" : "{remote} запитує зв’язок із {circle}",
    "The request to link {circle} with {remote} has been rejected" : "Запит на зв’язування {circle} із {remote} відхилено",
    "The request to link {remote} with {circle} has been canceled remotely" : "Запит на зв’язування {remote} із {circle} скасовано віддалено",
    "The request to link {circle} with {remote} has been accepted" : "Запит на зв’язування {circle} із {remote} прийнято",
    "You dismissed the request to link {remote} with {circle}" : "Ви відхилили запит на зв’язування {remote} із {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} відхилив запит на зв’язування {remote} із {circle}",
    "You canceled the request to link {circle} with {remote}" : "Ви скасували запит на зв’язування {circle} із {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} скасував запит на зв’язування {circle} із {remote}",
    "You accepted the request to link {remote} with {circle}" : "Ви прийняли запит на зв’язування {remote} із {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} прийняв запит на зв’язування {remote} із {circle}",
    "A link between {circle} and {remote} is now up and running" : "Зв’язок між {circle} і {remote} тепер працює",
    "The link between {circle} and {remote} has been shutdown remotely" : "Зв’язок між {circle} і {remote} віддалено відключено",
    "You closed the link between {circle} and {remote}" : "Ви закрили зв’язок між {circle} і {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} закрив зв’язок між {circle} і {remote}",
    "You joined {circle}" : "Ви приєдналися до {circle}",
    "{member} joined {circle}" : "{member} приєднався до {circle}",
    "You accepted the invitation to join {circle}" : "Ви прийняли запрошення приєднатися до {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} прийняв запрошення приєднатися до {circle}",
    "You added {member} as member to {circle}" : "Ви додали {member} учасником кола {circle}",
    "You have been added as member to {circle} by {author}" : "{author} додав вас учасником кола {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} додав {member} учасником кола {circle}",
    "You added {external} to {circle}" : "Ви додали {external} до {circle}",
    "{external} has been added to {circle} by {author}" : "{external} додано до {circle} {author}",
    "You accepted {member}'s request to join {circle}" : "Ви прийняли запит {member} приєднатися до {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Ваш запит на приєднання до {circle} прийнято {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Запит {member} приєднатися до {circle} був прийнятий {author}",
    "You left {circle}" : "Ви залишили {circle}",
    "{member} left {circle}" : "{member} залишив {circle}",
    "You declined the invitation to join {circle}" : "Ви відхилили запрошення приєднатися до {circle}",
    "{member} declined an invitation to join {circle}" : "{member} відхилив запрошення приєднатися до {circle}",
    "You cancelled your request to join {circle}" : "Ви скасували свій запит на приєднання до {circle}",
    "{member} cancelled his request to join {circle}" : "{member} скасував свій запит на приєднання до {circle}",
    "You removed {member} from {circle}" : "Ви вилучили {member} із {circle}",
    "You have been removed from {circle} by {author}" : "{author} вилучив вас із {circle}",
    "{member} has been removed from {circle} by {author}" : "{member} вилучено з кола {circle} автором {author}",
    "You removed {external} from {circle}" : "Ви вилучили {external} із {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} вилучено з кола {circle} автором {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Ви скасували запрошення користувача {member} приєднатися до {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Ваше запрошення приєднатися до {circle} було скасовано {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} скасував запрошення {member} приєднатися до {circle}",
    "You dismissed {member}'s request to join {circle}" : "Ви відхилили запит {member} приєднатися до {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Ваш запит на приєднання до {circle} відхилено {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} відхилив запит {member} на приєднання до {circle}",
    "You invited {member} to join {circle}" : "Ви запросили {member} приєднатися до {circle}",
    "You have been invited to join {circle} by {author}" : "{author} запросив вас приєднатися до {circle}",
    "{member} has been invited to join {circle} by {author}" : "{member} отримав запрошення приєднатися до {circle} від {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Ви змінили рівень участи {member} у колі {circle} на %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} змінив ваш рівень у колі {circle} на %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} змінив ваш рівень у колі {circle} на %1$s",
    "You sent a request to join {circle}" : "Ви надіслали запит на приєднання до {circle}",
    "{member} sent a request to join {circle}" : "{member} надіслав запит на приєднання до {circle}",
    "You are the new owner of {circle}" : "Ви новий власник {circle}",
    "{member} is the new owner of {circle}" : "{member} є новим власником {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Про події, що відбуваються в <strong>колі</strong>, учасником якого ви є",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Будь-яка важлива подія в <strong>колі</strong>, яке ви модеруєте",
    "On global events happening in any <strong>Circle</strong>" : "Про глобальні події, що відбуваються в будь-якому <strong>колі</strong>",
    "Single" : "Одиночний",
    "Personal" : "Особисте",
    "System" : "Система",
    "Visible" : "Видимий",
    "Open" : "Відкрити",
    "Invite" : "Запросити",
    "Join Request" : "Запит на приєднання",
    "Friends" : "Друзі",
    "Password Protected" : "Захищено паролем",
    "No Owner" : "Немає власника",
    "Hidden" : "Прихований",
    "Backend" : "Backend",
    "Local" : "Локально",
    "Root" : "Початок",
    "Circle Invite" : "Запрошення в коло",
    "Federated" : "Federated",
    "Mount point" : "Точка монтування",
    "Nextcloud Account" : "Обліковий запис Nextcloud",
    "Nextcloud Group" : "Група Nextcloud",
    "Email Address" : "Адреса електронної пошти",
    "Contact" : "Контакт",
    "Circle" : "Коло",
    "Nextcloud App" : "Застосунок Nextcloud",
    "Member" : "Учасник",
    "Moderator" : "Модератор",
    "Admin" : "Адміністратор",
    "Owner" : "Власник",
    "%s shared »%s« with you." : "%s надано доступ до \"%s\".",
    "%s shared »%s« with \"%s\"." : "%s надано доступ до \"%s\" із \"%s\".",
    "%s on %s" : "%s на %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$sподілився з вами \"%2$s\". \nНа вашу ел.скриньку було надіслано лист із посиланням для доступу до ресурсу.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s поділився з вами \"%2$s\". На вашу ел.скриньку було надіслано лист із посиланням для доступу до ресурсу.",
    "Password to access »%1$s« shared to you by %2$s" : "Пароль для доступу до %1$s, яким з вами поділився %2$s",
    "Password to access »%s«" : "Пароль доступу до \"%s\"",
    "It is protected with the following password:" : "Він захищений таким паролем:",
    "%1$s via %2$s" : "%1$s через %2$s",
    "Click the button below to open it." : "Для відкриття натисніть кнопку нижче.",
    "Open »%s«" : "Відкрити \"%s\"",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s поділився з вами кількома файлами. \nНа вашу ел.скриньку надійшов лист із посиланням для доступу до файлів.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s поділився з вами кількома файлами. На вашу ел.скриньку надійшов лист із посиланням для доступу до файлів.",
    "Password to access files shared to you by %1$s" : "Пароль для доступу до файлів, наданих вам %1$s",
    "Password to access files" : "Пароль для доступу до файлів",
    "%s shared multiple files with \"%s\"." : "%s поділився кількома файлами з \"%s\".",
    "%s shared multiple files with you." : "%s поділився з вами кількома файлами.",
    "Boot up" : "Завантаження",
    "Initialisation Nextcloud" : "Ініціалізація Nextcloud",
    "Initialisation Circles App" : "Ініціалізація застосунку Circle",
    "Fresh installation status" : "Статус свіжої інсталяції",
    "Building Local Database" : "Створення локальної бази даних",
    "Testing Basic Circle Creation" : "Тестування створення базового кола",
    "Adding local users and moderators" : "Додавання локальних користувачів і модераторів",
    "Circle not found" : "Коло не знайдено",
    "Circle not found " : "Коло не знайдено",
    "A circle with that name exists" : "Коло з такою назвою існує",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Ви не можете використовувати програму Circles, доки ваш адміністратор не дозволить принаймні один тип кіл",
    "This member does not exist" : "Цей учасник не існує",
    "This account is already a member of the circle" : "Цей обліковий запис уже є учасником кола",
    "Federated link not found" : "Об’єднане посилання не знайдено",
    "This feature is not available for personal circles" : "Ця функція недоступна для особистих кіл",
    "The circle is not federated" : "Коло не об'єднане",
    "You cannot join this circle" : "Ви не можете приєднатися до цього кола",
    "This member is not a moderator" : "Цей учасник не є модератором",
    "Insufficient privileges" : "Недостатні привілеї",
    "This member is the owner of the circle" : "Цей учасник є власником кола",
    "Level cannot be changed for this type of member" : "Рівень не можна змінити для цього типу учасників",
    "You are already a member of this circle" : "Ви вже є учасником цього кола",
    "You have been blocked from this circle" : "Вас заблоковано в цьому колі",
    "The account is already a member of this circle" : "Обліковий запис уже є учасником цього кола",
    "The account has already been invited into this circle" : "Обліковий запис уже запрошено до цього кола",
    "%s (Circle owned by %s)" : "%s (Коло належить %s)",
    "You are now a member of the Circle \"%2$s\"" : "Тепер ви учасник кола \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Вас запросив %1$s до кола \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s надіслав запит на участь у Колі \"%2$s\"",
    "Accept" : "Прийняти",
    "Refuse" : "Відмовитися",
    "Leave the circle" : "Вийти з кола",
    "%s" : "%s ",
    "Personal Circle" : "Особисте Коло",
    "%s owned by %s" : "%s належить %s",
    "You need a specify a type of circle" : "Потрібно вказати тип кола",
    "This member is not the owner of the circle" : "Цей учасник не є власником кола",
    "This member is not an admin of the circle" : "Цей учасник не є адміністратором кола",
    "Group contains too many members" : "Група містить забагато учасників",
    "This group does not exist" : "Ця група не існує",
    "This group is already linked to the circle" : "Ця група вже приєднана до кола",
    "You cannot edit level in a personal circle" : "Ви не можете редагувати рівень в особистому колі",
    "Group cannot be set as owner of a circle" : "Групу не можна встановити власником кола",
    "now" : "зараз",
    "This account does not exist" : "Цей обліковий запис не існує",
    "Email format is not valid" : "Недійсний формат електронної пошти",
    "This contact is not available" : "Цей контакт недоступний",
    "You have no permission to create a new circle" : "У вас немає дозволу на створення нового кола",
    "%s shared a file with \"%s\"." : "%sподілився файлом з \"%s\".",
    "%s shared a file with you." : "%s поділився з вами файлом.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s поділився з вами деяким вмістом. \nНа вашу ел.скриньку надійшов лист із посиланням для доступу до ресурсу.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s поділився з вами деяким вмістом. На вашу ел.скриньку надійшов лист із посиланням для доступу до ресурсу.",
    "Password to access content shared with you by %1$s" : "Пароль для доступу до вмісту, яким з вами поділився %1$s",
    "Password to access content" : "Пароль для доступу до вмісту",
    "This item is already shared with this circle" : "Цей елемент уже надано спільно для цього кола",
    "Could not find share" : "Не вдалося знайти спільний доступ",
    "Bring cloud-users closer together." : "Зближіть користувачів хмари.",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Кола дозволяють людям створювати власні групи людей/колег/друзів. \nПотім ці групи людей (або «кола») можуть використовуватися будь-якою іншою програмою для спільного використання.",
    "No files in here" : "Тут немає файлів",
    "No entries found in this folder" : "У цьому каталозі нічого немає",
    "Name" : "Ім'я",
    "Size" : "Розмір",
    "Modified" : "Змінено",
    "Nextcloud User" : "Користувач Nextcloud",
    "This user is already a member of the circle" : "Цей користувач уже є учасником кола",
    "The user is already a member of this circle" : "Користувач уже є учасником цього кола",
    "The user has already been invited into this circle" : "Користувача вже запрошено до цього кола",
    "This user does not exist" : "Цей користувач не існує",
    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "Кола дозволяють вашим користувачам створювати власні групи користувачів/колег/друзів. \nЦі групи користувачів (або «кола») потім можуть використовуватися будь-якою іншою програмою для спільного використання."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
